Learn R Programming

CytobankBridgeR (version 1.0.0)

fcs_files.download_fcs_files_stable: FCS Files

Description

FCS File High Level Functions

Usage

fcs_files.download_fcs_files_stable(UserSession, experiment_id, fcs_files,
  directory = getwd(), zip_download = TRUE, timeout = 300)

Arguments

UserSession

Cytobank UserSession object

experiment_id

integer representing an experiment ID

fcs_files

vector/list of integers representing a list of FCS file IDs

directory

character representing a specific directory to which the file will be downloaded (optional ending directory slash), if left empty, the default will be the current working directory [optional]

zip_download

logical representing whether or not to download each file one by one via ZIP download [default] or normal FCS download [optional]

timeout

integer representing the request timeout time in seconds [optional]

Details

fcs_files.download_fcs_files_stable Apply cluster gate(s) to specific clusters via an integer vector

Examples

Run this code
# NOT RUN {
fcs_files.download_fcs_files_stable(cyto_session, 22, fcs_files=c(1,2,3),
  directory="/my/new/download/directory/")
# }
# NOT RUN {
# Authenticate via username/password
cyto_session <- authenticate(site="premium", username="cyril_cytometry", password="cytobank_rocks!")
# Authenticate via auth_token
cyto_session <- authenticate(site="premium", auth_token="my_secret_auth_token")
# }

Run the code above in your browser using DataLab