Gates High Level Functions
gates.apply_cluster_gates(UserSession, experiment_id, name, clusters,
channel_name, integer_min = 1, integer_max = max(clusters),
grouped = FALSE, timeout = 60)Cytobank UserSession object (created via the authenticate function)
integer representing an experiments ID
character representing a cluster prefix (if grouped=FALSE) or multicluster gate name
integer vector representing the clusters to gate
- There are 2 modes of operation:
1) grouped=FALSE: clusters represent individual integer clusters to gate, this will create multiple gates that represents multiple individual populations
2) grouped=TRUE: clusters represent a multi-integer cluster to gate, this will create one gate that represents one population around the integer clusters specified
character representing the channel short name
integer representing the minimum cluster integer for setting scales [optional] - The default is set to 1, this assumes clusters begin at 1, but can be changed if there is any +/- offset - The minimum scale will be set to integer_min-1 (0 by)
integer representing the maximum cluster integer for setting scales [optional]
- The default is the maximum number presented within the clusters vector, but can be set to any integer
- The max scale will be set to integer_max+1
logical representing whether to gate a vector of integer clusters as individual integer clusters (grouped=FALSE), or together as a single multicluster (grouped=TRUE)
integer representing the request timeout time in seconds [optional]
gates.apply_cluster_gates Apply cluster gate(s) to specific clusters via an integer vector
# NOT RUN {
gates.apply_cluster_gates(cyto_session, 22, name="cluster_names",
clusters=c(1,5,9), channel_name="cluster_id")
# }
Run the code above in your browser using DataLab